@@ -1,5 +1,4 @@
 import asyncio
-import sys
 from typing import Any
 from typing import Dict
 from typing import List
@@ -21,11 +20,17 @@ async def start(hub, contexts: Dict[str, List[Dict[str, Any]]]):
     bus: asyncio.Queue = await hub.evbus.broker.init()
 
     while True:
-        item = await bus.get()
-        event = item[1]
+        event = await bus.get()
         if event is STOP_ITERATION:
-            hub.log.info("Event bus was forced to stop")
-            return
+            # Check if there are more events after terminal (STOP_ITERATION) events
+            if bus.qsize() > 0:
+                # It should push the terminal (STOP_ITERATION) event in the back of the queue
+                # This is to make sure all events are processed before stopping
+                await hub.evbus.BUS.put(STOP_ITERATION)
+                continue
+            else:
+                hub.log.info("Event bus was forced to stop")
+                return
         await hub.evbus.broker.propagate(contexts=contexts, event=event)
 
 
@@ -34,9 +39,7 @@ async def stop(hub):
     Stop the event bus
     """
     hub.log.debug("Stopping the event bus")
-    bus: asyncio.PriorityQueue = hub.evbus.BUS
-    # This has to be the highest priority, so that it is processed in the last
-    bus.put_nowait((sys.maxsize, STOP_ITERATION))
+    hub.evbus.BUS.put_nowait(STOP_ITERATION)
 
 
 async def join(hub):
